package autofeature;

import autofeature.parser.SpecificationReader;
import autofeature.intermediate.Specification;
import autofeature.generator.ACCGenerator;
import java.io.File;
import java.io.FileReader;
import org.json.simple.JSONObject;
import org.json.simple.JSONValue;


/**
 *
 * Main class 
 *
 * @author Hendrik Speidel - speidel@fmi.uni-passau.de
 */
public class Main {

    /**
     *
     * @param args the command line arguments
     *              only the first is regarded. The rest is silently ignored.
     *              If none given this falls back to input.spec
     *              Relative to location of test dir ... will change!
     *
     * @throws Exception to see whats going wrong early
     */
    public static void main(String[] args) throws Exception {
        
        String filename = "";
        if (args.length == 0) {
            System.out.println("Usage: java cpawsl.Main <specfile>");
            System.exit(1);
        } else {
            if (!args[0].startsWith("/")) {
                filename = new File("").getAbsolutePath() + "/" + args[0];
            } else {
                filename = args[0];
            }
        }

        File inputFile = new File(filename);

        if (!inputFile.isFile()) {
            System.err.println("File " + filename + " could not be found!");
            System.exit(1);
        }

        File metafile = new File(inputFile.getParentFile(), "roles.meta");

        JSONObject meta = (JSONObject) JSONValue.parse(new FileReader(metafile));

        SpecificationReader reader = new SpecificationReader();
        ACCGenerator generator = new ACCGenerator(meta);

        //build AST
        Specification specification = reader.readFile(inputFile.getAbsolutePath());

        //generate AspectC output
        generator.transform(specification);

    }

}
